import {StyleSheet, View, ViewProps, ViewStyle} from 'react-native';
import React from 'react';

/**
 * @interface
 * @param {number} radius - The radius of the circle.
 * @param {string} backgroundColor - The background color of the circle
 **/
export interface SafecamCircleProps extends ViewProps {
  radius?: number;
  backgroundColor?: string;
}

/**
 * @component
 * Represents a Circle instance
 * @param {number} radius - The radius of the circle.
 * @param {string} backgroundColor - The background color of the circle
 * @example
 * <Circle radius={10} backgroundColor="#fff"/>
 */

const SafecamCircle: React.FC<SafecamCircleProps> = ({
  radius = 10,
  backgroundColor = 'gray',
  ...props
}) => {
  const styles = StyleSheet.create({
    root: {
      ...(props.style as ViewStyle),
      height: radius,
      width: radius,
      backgroundColor,
      borderRadius: radius / 2,
    },
  });

  return (
    <View {...props} style={styles.root}>
      {props.children}
    </View>
  );
};

export default SafecamCircle;
